.. image:: images/zhinst_logo_sep_horiz_2019_1000.png
   :width: 600

|
|
|

Welcome to the Documentation for :mod:`zhinst-toolkit`!
=======================================================


The *Zurich Instruments Toolkit* is an extension of our Python API `ziPython`. 
It facilitates the control of *Zurich Instruments* devices like the *HDAWG*, 
*UHFQA*, *UHFLI*, *MFLI* or *PQSC*. The Python package :mod:`zhinst-toolkit` 
forms the basis for high-level instrument drivers within measurement frameworks 
like QCoDeS_ or Labber_. The :mod:`zhinst-toolkit` can however also be used by 
itself.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   about/index
   start/index
   zhinst-toolkit/index
   examples/index
   changelog/index
   license/index



Index
=====

* :ref:`genindex`

.. _QCoDeS: https://qcodes.github.io/Qcodes/index.html
.. _Labber: https://labber.org/
